@@ -502,7 +502,7 @@ N_word BitVector_Mask(N_int bits)           /* bit vector mask (unused bits) */
 
 charptr BitVector_Version(void)
 {
-    return((charptr)"5.4");
+    return((charptr)"5.5");
 }
 
 N_int BitVector_Word_Bits(void)
@@ -2488,7 +2488,7 @@ ErrCode BitVector_Mul_Pos(wordptr X, wordptr Y, wordptr Z)
 
 ErrCode BitVector_Multiply(wordptr X, wordptr Y, wordptr Z)
 {
-    ErrCode error;
+    ErrCode error = ErrCode_Ok;
     N_word  bit_x = bits_(X);
     N_word  bit_y = bits_(Y);
     N_word  bit_z = bits_(Z);
@@ -3254,11 +3254,12 @@ void Matrix_Transpose(wordptr X, N_int rowsX, N_int colsX,
 }
 
 /*****************************************************************************/
-/*  VERSION:  5.4                                                            */
+/*  VERSION:  5.5                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
+/*    Version 5.5  21.09.98  Fixed bug of uninitialized "error" in Multiply. */
 /*    Version 5.4  07.09.98  Fixed bug of uninitialized "error" in Divide.   */
 /*    Version 5.3  12.05.98  Improved Norm. Completed history.               */
 /*    Version 5.2  31.03.98  Improved Norm.                                  */
